summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kexisql3/src/sqliteInt.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/3rdparty/kexisql3/src/sqliteInt.h')
-rw-r--r--kexi/3rdparty/kexisql3/src/sqliteInt.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kexi/3rdparty/kexisql3/src/sqliteInt.h b/kexi/3rdparty/kexisql3/src/sqliteInt.h
index 74916805..153b537b 100644
--- a/kexi/3rdparty/kexisql3/src/sqliteInt.h
+++ b/kexi/3rdparty/kexisql3/src/sqliteInt.h
@@ -119,7 +119,7 @@
** The maximum number of attached databases. This must be at least 2
** in order to support the main database file (0) and the file used to
** hold temporary tables (1). And it must be less than 32 because
** we use a bittqmask of databases with a u32 in places (for example
** the Parse.cookieMask field).
*/
#define MAX_ATTACHED 10
@@ -976,9 +976,9 @@ struct IdList {
};
/*
** The bittqmask datatype defined below is used for various optimizations.
*/
-typedef unsigned int Bittqmask;
+typedef unsigned int Bitmask;
/*
** The following structure describes the FROM clause of a SELECT statement.
@@ -1004,7 +1004,7 @@ struct SrcList {
i16 iCursor; /* The VDBE cursor number used to access this table */
Expr *pOn; /* The ON clause of a join */
IdList *pUsing; /* The USING clause of a join */
- Bittqmask colUsed; /* Bit N (1<<N) set if column N or pTab is used */
+ Bitmask colUsed; /* Bit N (1<<N) set if column N or pTab is used */
} a[1]; /* One entry for each identifier on the list */
};
@@ -1076,7 +1076,7 @@ struct WhereInfo {
** the context containing the match is incremented.
**
** Each subquery gets a new NameContext. The pNext field points to the
-** NameContext in the tqparent query. Thus the process of scanning the
+** NameContext in the parent query. Thus the process of scanning the
** NameContext list corresponds to searching through successively outer
** subqueries looking for a match.
*/
@@ -1176,7 +1176,7 @@ struct Parse {
int nMem; /* Number of memory cells used so far */
int nSet; /* Number of sets used so far */
u32 writeMask; /* Start a write transaction on these databases */
- u32 cookieMask; /* Bittqmask of schema verified databases */
+ u32 cookieMask; /* Bitmask of schema verified databases */
int cookieGoto; /* Address of OP_Goto to cookie verifier subroutine */
int cookieValue[MAX_ATTACHED+2]; /* Values of cookies to verify */
@@ -1328,9 +1328,9 @@ struct TriggerStep {
*
* struct TriggerStack has a "pNext" member, to allow linked lists to be
* constructed. When coding nested triggers (triggers fired by other triggers)
- * each nested trigger stores its tqparent trigger's TriggerStack as the "pNext"
+ * each nested trigger stores its parent trigger's TriggerStack as the "pNext"
* pointer. Once the nested trigger has been coded, the pNext value is restored
- * to the pTriggerStack member of the Parse stucture and coding of the tqparent
+ * to the pTriggerStack member of the Parse stucture and coding of the parent
* trigger continues.
*
* Before a nested trigger is coded, the linked list pointed to by the
@@ -119,7 +119,7 @@
** in order to support the main database file (0) and the file used to
** hold temporary tables (1). And it must be less than 32 because
-** we use a bittqmask of databases with a u32 in places (for example
+** we use a bitmask of databases with a u32 in places (for example
** the Parse.cookieMask field).
*/
@@ -976,9 +976,9 @@ struct IdList {
};
/*
-** The bittqmask datatype defined below is used for various optimizations.
+** The bitmask datatype defined below is used for various optimizations.
*/